==> zio-aws-opsworkscm_2.13-5.19.26.1-sources.jar: zio/aws/opsworkscm/model/Backup.scala <==
package zio.aws.opsworkscm.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.opsworkscm.model.primitives.{
  TimeWindowDefinition,
  Timestamp,
  BackupId,
  Integer,
  ServerName
}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class Backup(
    backupArn: Optional[String] = Optional.Absent,
    backupId: Optional[BackupId] = Optional.Absent,
    backupType: Optional[zio.aws.opsworkscm.model.BackupType] = Optional.Absent,
    createdAt: Optional[Timestamp] = Optional.Absent,
    description: Optional[String] = Optional.Absent,
    engine: Optional[String] = Optional.Absent,
    engineModel: Optional[String] = Optional.Absent,
    engineVersion: Optional[String] = Optional.Absent,
    instanceProfileArn: Optional[String] = Optional.Absent,
    instanceType: Optional[String] = Optional.Absent,
    keyPair: Optional[String] = Optional.Absent,
    preferredBackupWindow: Optional[TimeWindowDefinition] = Optional.Absent,
    preferredMaintenanceWindow: Optional[TimeWindowDefinition] =
      Optional.Absent,
    s3DataSize: Optional[Integer] = Optional.Absent,
    s3DataUrl: Optional[String] = Optional.Absent,
    s3LogUrl: Optional[String] = Optional.Absent,
    securityGroupIds: Optional[Iterable[String]] = Optional.Absent,
    serverName: Optional[ServerName] = Optional.Absent,
    serviceRoleArn: Optional[String] = Optional.Absent,
    status: Optional[zio.aws.opsworkscm.model.BackupStatus] = Optional.Absent,
    statusDescription: Optional[String] = Optional.Absent,
    subnetIds: Optional[Iterable[String]] = Optional.Absent,
    toolsVersion: Optional[String] = Optional.Absent,
    userArn: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opsworkscm.model.Backup = {
    import Backup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opsworkscm.model.Backup
      .builder()
      .optionallyWith(backupArn.map(value => value: java.lang.String))(
        _.backupArn
      )
      .optionallyWith(
        backupId.map(value => BackupId.unwrap(value): java.lang.String)
      )(_.backupId)
      .optionallyWith(backupType.map(value => value.unwrap))(_.backupType)
      .optionallyWith(createdAt.map(value => Timestamp.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(engine.map(value => value: java.lang.String))(_.engine)
      .optionallyWith(engineModel.map(value => value: java.lang.String))(
        _.engineModel
      )
      .optionallyWith(engineVersion.map(value => value: java.lang.String))(
        _.engineVersion
      )
      .optionallyWith(instanceProfileArn.map(value => value: java.lang.String))(
        _.instanceProfileArn
      )
      .optionallyWith(instanceType.map(value => value: java.lang.String))(
        _.instanceType
      )
      .optionallyWith(keyPair.map(value => value: java.lang.String))(_.keyPair)
      .optionallyWith(
        preferredBackupWindow.map(value =>
          TimeWindowDefinition.unwrap(value): java.lang.String
        )
      )(_.preferredBackupWindow)
      .optionallyWith(
        preferredMaintenanceWindow.map(value =>
          TimeWindowDefinition.unwrap(value): java.lang.String
        )
      )(_.preferredMaintenanceWindow)
      .optionallyWith(s3DataSize.map(value => value: java.lang.Integer))(
        _.s3DataSize
      )
      .optionallyWith(s3DataUrl.map(value => value: java.lang.String))(
        _.s3DataUrl
      )
      .optionallyWith(s3LogUrl.map(value => value: java.lang.String))(
        _.s3LogUrl
      )
      .optionallyWith(
        securityGroupIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.securityGroupIds)
      .optionallyWith(
        serverName.map(value => ServerName.unwrap(value): java.lang.String)
      )(_.serverName)
      .optionallyWith(serviceRoleArn.map(value => value: java.lang.String))(
        _.serviceRoleArn
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(statusDescription.map(value => value: java.lang.String))(
        _.statusDescription
      )
      .optionallyWith(
        subnetIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.subnetIds)
      .optionallyWith(toolsVersion.map(value => value: java.lang.String))(
        _.toolsVersion
      )
      .optionallyWith(userArn.map(value => value: java.lang.String))(_.userArn)
      .build()
  }
  def asReadOnly: zio.aws.opsworkscm.model.Backup.ReadOnly =
    zio.aws.opsworkscm.model.Backup.wrap(buildAwsValue())
}
object Backup {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.opsworkscm.model.Backup] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opsworkscm.model.Backup =
      zio.aws.opsworkscm.model.Backup(
        backupArn.map(value => value),
        backupId.map(value => value),
        backupType.map(value => value),
        createdAt.map(value => value),
        description.map(value => value),
        engine.map(value => value),
        engineModel.map(value => value),
        engineVersion.map(value => value),
        instanceProfileArn.map(value => value),
        instanceType.map(value => value),
        keyPair.map(value => value),
        preferredBackupWindow.map(value => value),
        preferredMaintenanceWindow.map(value => value),
        s3DataSize.map(value => value),
        s3DataUrl.map(value => value),
        s3LogUrl.map(value => value),
        securityGroupIds.map(value => value),
        serverName.map(value => value),
        serviceRoleArn.map(value => value),
        status.map(value => value),
        statusDescription.map(value => value),
        subnetIds.map(value => value),
        toolsVersion.map(value => value),
        userArn.map(value => value)
      )
    def backupArn: Optional[String]
    def backupId: Optional[BackupId]
    def backupType: Optional[zio.aws.opsworkscm.model.BackupType]
    def createdAt: Optional[Timestamp]
    def description: Optional[String]
    def engine: Optional[String]
    def engineModel: Optional[String]
    def engineVersion: Optional[String]
    def instanceProfileArn: Optional[String]
    def instanceType: Optional[String]
    def keyPair: Optional[String]
    def preferredBackupWindow: Optional[TimeWindowDefinition]
    def preferredMaintenanceWindow: Optional[TimeWindowDefinition]
    def s3DataSize: Optional[Integer]
    def s3DataUrl: Optional[String]
    def s3LogUrl: Optional[String]
    def securityGroupIds: Optional[List[String]]
    def serverName: Optional[ServerName]
    def serviceRoleArn: Optional[String]
    def status: Optional[zio.aws.opsworkscm.model.BackupStatus]
    def statusDescription: Optional[String]
    def subnetIds: Optional[List[String]]
    def toolsVersion: Optional[String]
    def userArn: Optional[String]
    def getBackupArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("backupArn", backupArn)
    def getBackupId: ZIO[Any, AwsError, BackupId] =
      AwsError.unwrapOptionField("backupId", backupId)
    def getBackupType: ZIO[Any, AwsError, zio.aws.opsworkscm.model.BackupType] =
      AwsError.unwrapOptionField("backupType", backupType)
    def getCreatedAt: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getEngine: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engine", engine)
    def getEngineModel: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engineModel", engineModel)
    def getEngineVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engineVersion", engineVersion)
    def getInstanceProfileArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceProfileArn", instanceProfileArn)
    def getInstanceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceType", instanceType)
    def getKeyPair: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("keyPair", keyPair)
    def getPreferredBackupWindow: ZIO[Any, AwsError, TimeWindowDefinition] =
      AwsError.unwrapOptionField("preferredBackupWindow", preferredBackupWindow)
    def getPreferredMaintenanceWindow
        : ZIO[Any, AwsError, TimeWindowDefinition] = AwsError.unwrapOptionField(
      "preferredMaintenanceWindow",
      preferredMaintenanceWindow
    )
    def getS3DataSize: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("s3DataSize", s3DataSize)
    def getS3DataUrl: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("s3DataUrl", s3DataUrl)
    def getS3LogUrl: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("s3LogUrl", s3LogUrl)
    def getSecurityGroupIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("securityGroupIds", securityGroupIds)
    def getServerName: ZIO[Any, AwsError, ServerName] =
      AwsError.unwrapOptionField("serverName", serverName)
    def getServiceRoleArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("serviceRoleArn", serviceRoleArn)
    def getStatus: ZIO[Any, AwsError, zio.aws.opsworkscm.model.BackupStatus] =
      AwsError.unwrapOptionField("status", status)
    def getStatusDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("statusDescription", statusDescription)
    def getSubnetIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("subnetIds", subnetIds)
    def getToolsVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("toolsVersion", toolsVersion)
    def getUserArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("userArn", userArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opsworkscm.model.Backup
  ) extends zio.aws.opsworkscm.model.Backup.ReadOnly {
    override val backupArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.backupArn())
      .map(value => value: String)
    override val backupId: Optional[BackupId] = zio.aws.core.internal
      .optionalFromNullable(impl.backupId())
      .map(value => zio.aws.opsworkscm.model.primitives.BackupId(value))
    override val backupType: Optional[zio.aws.opsworkscm.model.BackupType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.backupType())
        .map(value => zio.aws.opsworkscm.model.BackupType.wrap(value))
    override val createdAt: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => zio.aws.opsworkscm.model.primitives.Timestamp(value))
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val engine: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.engine())
      .map(value => value: String)
    override val engineModel: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.engineModel())
      .map(value => value: String)
    override val engineVersion: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.engineVersion())
      .map(value => value: String)
    override val instanceProfileArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceProfileArn())
      .map(value => value: String)
    override val instanceType: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceType())
      .map(value => value: String)
    override val keyPair: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.keyPair())
      .map(value => value: String)
    override val preferredBackupWindow: Optional[TimeWindowDefinition] =
      zio.aws.core.internal
        .optionalFromNullable(impl.preferredBackupWindow())
        .map(value =>
          zio.aws.opsworkscm.model.primitives.TimeWindowDefinition(value)
        )
    override val preferredMaintenanceWindow: Optional[TimeWindowDefinition] =
      zio.aws.core.internal
        .optionalFromNullable(impl.preferredMaintenanceWindow())
        .map(value =>
          zio.aws.opsworkscm.model.primitives.TimeWindowDefinition(value)
        )
    override val s3DataSize: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.s3DataSize())
      .map(value => value: Integer)
    override val s3DataUrl: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.s3DataUrl())
      .map(value => value: String)
    override val s3LogUrl: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.s3LogUrl())
      .map(value => value: String)
    override val securityGroupIds: Optional[List[String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.securityGroupIds())
        .map(value =>
          value.asScala.map { item =>
            item: String
          }.toList
        )
    override val serverName: Optional[ServerName] = zio.aws.core.internal
      .optionalFromNullable(impl.serverName())
      .map(value => zio.aws.opsworkscm.model.primitives.ServerName(value))
    override val serviceRoleArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.serviceRoleArn())
      .map(value => value: String)
    override val status: Optional[zio.aws.opsworkscm.model.BackupStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.opsworkscm.model.BackupStatus.wrap(value))
    override val statusDescription: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.statusDescription())
      .map(value => value: String)
    override val subnetIds: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.subnetIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val toolsVersion: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.toolsVersion())
      .map(value => value: String)
    override val userArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.userArn())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.opsworkscm.model.Backup
  ): zio.aws.opsworkscm.model.Backup.ReadOnly = new Wrapper(impl)
}

==> zio-aws-opsworkscm_3-5.17.126.2-sources.jar: zio/aws/opsworkscm/model/Backup.scala <==
package zio.aws.opsworkscm.model
import zio.ZIO
import zio.aws.opsworkscm.model.primitives.{
  TimeWindowDefinition,
  Timestamp,
  BackupId,
  Integer,
  ServerName
}
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class Backup(
    backupArn: Option[String] = None,
    backupId: Option[BackupId] = None,
    backupType: Option[zio.aws.opsworkscm.model.BackupType] = None,
    createdAt: Option[Timestamp] = None,
    description: Option[String] = None,
    engine: Option[String] = None,
    engineModel: Option[String] = None,
    engineVersion: Option[String] = None,
    instanceProfileArn: Option[String] = None,
    instanceType: Option[String] = None,
    keyPair: Option[String] = None,
    preferredBackupWindow: Option[TimeWindowDefinition] = None,
    preferredMaintenanceWindow: Option[TimeWindowDefinition] = None,
    s3DataSize: Option[Integer] = None,
    s3DataUrl: Option[String] = None,
    s3LogUrl: Option[String] = None,
    securityGroupIds: Option[Iterable[String]] = None,
    serverName: Option[ServerName] = None,
    serviceRoleArn: Option[String] = None,
    status: Option[zio.aws.opsworkscm.model.BackupStatus] = None,
    statusDescription: Option[String] = None,
    subnetIds: Option[Iterable[String]] = None,
    toolsVersion: Option[String] = None,
    userArn: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opsworkscm.model.Backup = {
    import Backup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opsworkscm.model.Backup
      .builder()
      .optionallyWith(backupArn.map(value => value: java.lang.String))(
        _.backupArn
      )
      .optionallyWith(
        backupId.map(value => BackupId.unwrap(value): java.lang.String)
      )(_.backupId)
      .optionallyWith(backupType.map(value => value.unwrap))(_.backupType)
      .optionallyWith(createdAt.map(value => Timestamp.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(engine.map(value => value: java.lang.String))(_.engine)
      .optionallyWith(engineModel.map(value => value: java.lang.String))(
        _.engineModel
      )
      .optionallyWith(engineVersion.map(value => value: java.lang.String))(
        _.engineVersion
      )
      .optionallyWith(instanceProfileArn.map(value => value: java.lang.String))(
        _.instanceProfileArn
      )
      .optionallyWith(instanceType.map(value => value: java.lang.String))(
        _.instanceType
      )
      .optionallyWith(keyPair.map(value => value: java.lang.String))(_.keyPair)
      .optionallyWith(
        preferredBackupWindow.map(value =>
          TimeWindowDefinition.unwrap(value): java.lang.String
        )
      )(_.preferredBackupWindow)
      .optionallyWith(
        preferredMaintenanceWindow.map(value =>
          TimeWindowDefinition.unwrap(value): java.lang.String
        )
      )(_.preferredMaintenanceWindow)
      .optionallyWith(
        s3DataSize.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.s3DataSize)
      .optionallyWith(s3DataUrl.map(value => value: java.lang.String))(
        _.s3DataUrl
      )
      .optionallyWith(s3LogUrl.map(value => value: java.lang.String))(
        _.s3LogUrl
      )
      .optionallyWith(
        securityGroupIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.securityGroupIds)
      .optionallyWith(
        serverName.map(value => ServerName.unwrap(value): java.lang.String)
      )(_.serverName)
      .optionallyWith(serviceRoleArn.map(value => value: java.lang.String))(
        _.serviceRoleArn
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(statusDescription.map(value => value: java.lang.String))(
        _.statusDescription
      )
      .optionallyWith(
        subnetIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.subnetIds)
      .optionallyWith(toolsVersion.map(value => value: java.lang.String))(
        _.toolsVersion
      )
      .optionallyWith(userArn.map(value => value: java.lang.String))(_.userArn)
      .build()
  }
  def asReadOnly: zio.aws.opsworkscm.model.Backup.ReadOnly =
    zio.aws.opsworkscm.model.Backup.wrap(buildAwsValue())
}
object Backup {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.opsworkscm.model.Backup] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opsworkscm.model.Backup =
      zio.aws.opsworkscm.model.Backup(
        backupArn.map(value => value),
        backupId.map(value => value),
        backupType.map(value => value),
        createdAt.map(value => value),
        description.map(value => value),
        engine.map(value => value),
        engineModel.map(value => value),
        engineVersion.map(value => value),
        instanceProfileArn.map(value => value),
        instanceType.map(value => value),
        keyPair.map(value => value),
        preferredBackupWindow.map(value => value),
        preferredMaintenanceWindow.map(value => value),
        s3DataSize.map(value => value),
        s3DataUrl.map(value => value),
        s3LogUrl.map(value => value),
        securityGroupIds.map(value => value),
        serverName.map(value => value),
        serviceRoleArn.map(value => value),
        status.map(value => value),
        statusDescription.map(value => value),
        subnetIds.map(value => value),
        toolsVersion.map(value => value),
        userArn.map(value => value)
      )
    def backupArn: Option[String]
    def backupId: Option[BackupId]
    def backupType: Option[zio.aws.opsworkscm.model.BackupType]
    def createdAt: Option[Timestamp]
    def description: Option[String]
    def engine: Option[String]
    def engineModel: Option[String]
    def engineVersion: Option[String]
    def instanceProfileArn: Option[String]
    def instanceType: Option[String]
    def keyPair: Option[String]
    def preferredBackupWindow: Option[TimeWindowDefinition]
    def preferredMaintenanceWindow: Option[TimeWindowDefinition]
    def s3DataSize: Option[Integer]
    def s3DataUrl: Option[String]
    def s3LogUrl: Option[String]
    def securityGroupIds: Option[List[String]]
    def serverName: Option[ServerName]
    def serviceRoleArn: Option[String]
    def status: Option[zio.aws.opsworkscm.model.BackupStatus]
    def statusDescription: Option[String]
    def subnetIds: Option[List[String]]
    def toolsVersion: Option[String]
    def userArn: Option[String]
    def getBackupArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("backupArn", backupArn)
    def getBackupId: ZIO[Any, AwsError, BackupId] =
      AwsError.unwrapOptionField("backupId", backupId)
    def getBackupType: ZIO[Any, AwsError, zio.aws.opsworkscm.model.BackupType] =
      AwsError.unwrapOptionField("backupType", backupType)
    def getCreatedAt: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getEngine: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engine", engine)
    def getEngineModel: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engineModel", engineModel)
    def getEngineVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engineVersion", engineVersion)
    def getInstanceProfileArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceProfileArn", instanceProfileArn)
    def getInstanceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceType", instanceType)
    def getKeyPair: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("keyPair", keyPair)
    def getPreferredBackupWindow: ZIO[Any, AwsError, TimeWindowDefinition] =
      AwsError.unwrapOptionField("preferredBackupWindow", preferredBackupWindow)
    def getPreferredMaintenanceWindow
        : ZIO[Any, AwsError, TimeWindowDefinition] = AwsError.unwrapOptionField(
      "preferredMaintenanceWindow",
      preferredMaintenanceWindow
    )
    def getS3DataSize: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("s3DataSize", s3DataSize)
    def getS3DataUrl: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("s3DataUrl", s3DataUrl)
    def getS3LogUrl: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("s3LogUrl", s3LogUrl)
    def getSecurityGroupIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("securityGroupIds", securityGroupIds)
    def getServerName: ZIO[Any, AwsError, ServerName] =
      AwsError.unwrapOptionField("serverName", serverName)
    def getServiceRoleArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("serviceRoleArn", serviceRoleArn)
    def getStatus: ZIO[Any, AwsError, zio.aws.opsworkscm.model.BackupStatus] =
      AwsError.unwrapOptionField("status", status)
    def getStatusDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("statusDescription", statusDescription)
    def getSubnetIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("subnetIds", subnetIds)
    def getToolsVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("toolsVersion", toolsVersion)
    def getUserArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("userArn", userArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opsworkscm.model.Backup
  ) extends zio.aws.opsworkscm.model.Backup.ReadOnly {
    override val backupArn: Option[String] =
      scala.Option(impl.backupArn()).map(value => value: String)
    override val backupId: Option[BackupId] = scala
      .Option(impl.backupId())
      .map(value => zio.aws.opsworkscm.model.primitives.BackupId(value))
    override val backupType: Option[zio.aws.opsworkscm.model.BackupType] = scala
      .Option(impl.backupType())
      .map(value => zio.aws.opsworkscm.model.BackupType.wrap(value))
    override val createdAt: Option[Timestamp] = scala
      .Option(impl.createdAt())
      .map(value => zio.aws.opsworkscm.model.primitives.Timestamp(value))
    override val description: Option[String] =
      scala.Option(impl.description()).map(value => value: String)
    override val engine: Option[String] =
      scala.Option(impl.engine()).map(value => value: String)
    override val engineModel: Option[String] =
      scala.Option(impl.engineModel()).map(value => value: String)
    override val engineVersion: Option[String] =
      scala.Option(impl.engineVersion()).map(value => value: String)
    override val instanceProfileArn: Option[String] =
      scala.Option(impl.instanceProfileArn()).map(value => value: String)
    override val instanceType: Option[String] =
      scala.Option(impl.instanceType()).map(value => value: String)
    override val keyPair: Option[String] =
      scala.Option(impl.keyPair()).map(value => value: String)
    override val preferredBackupWindow: Option[TimeWindowDefinition] = scala
      .Option(impl.preferredBackupWindow())
      .map(value =>
        zio.aws.opsworkscm.model.primitives.TimeWindowDefinition(value)
      )
    override val preferredMaintenanceWindow: Option[TimeWindowDefinition] =
      scala
        .Option(impl.preferredMaintenanceWindow())
        .map(value =>
          zio.aws.opsworkscm.model.primitives.TimeWindowDefinition(value)
        )
    override val s3DataSize: Option[Integer] = scala
      .Option(impl.s3DataSize())
      .map(value => zio.aws.opsworkscm.model.primitives.Integer(value))
    override val s3DataUrl: Option[String] =
      scala.Option(impl.s3DataUrl()).map(value => value: String)
    override val s3LogUrl: Option[String] =
      scala.Option(impl.s3LogUrl()).map(value => value: String)
    override val securityGroupIds: Option[List[String]] = scala
      .Option(impl.securityGroupIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val serverName: Option[ServerName] = scala
      .Option(impl.serverName())
      .map(value => zio.aws.opsworkscm.model.primitives.ServerName(value))
    override val serviceRoleArn: Option[String] =
      scala.Option(impl.serviceRoleArn()).map(value => value: String)
    override val status: Option[zio.aws.opsworkscm.model.BackupStatus] = scala
      .Option(impl.status())
      .map(value => zio.aws.opsworkscm.model.BackupStatus.wrap(value))
    override val statusDescription: Option[String] =
      scala.Option(impl.statusDescription()).map(value => value: String)
    override val subnetIds: Option[List[String]] = scala
      .Option(impl.subnetIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val toolsVersion: Option[String] =
      scala.Option(impl.toolsVersion()).map(value => value: String)
    override val userArn: Option[String] =
      scala.Option(impl.userArn()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.opsworkscm.model.Backup
  ): zio.aws.opsworkscm.model.Backup.ReadOnly = new Wrapper(impl)
}
